@@ -121,6 +121,7 @@ enum
     ALBUM_FONT_STYLE,
     ALBUM_FONT_WEIGHT,
     ALBUM_ROW_FOREGROUND,
+    ALBUM_ALL_ALBUMS_ROW,
     ALBUM_COLUMN_COUNT
 };
 
@@ -143,6 +144,11 @@ GtkWidget *RenameDirectoryPreviewLabel;
  **************/
 
 GtkWidget   *Create_Browser_Items    (GtkWidget *parent);
+
+void browser_album_model_clear (void);
+void browser_artist_model_clear (void);
+void browser_file_model_clear (void);
+
 gboolean     Browser_Tree_Select_Dir (const gchar *current_path);
 void         Browser_Tree_Rebuild    (gchar *path_to_load);
 void         Browser_Tree_Collapse   (void);
